/*
 * BYOND String Utilities
 * StringBuilder.h
 *
 *  Created on: 15 Jan 2011
 *      Author: Stephen Badger (Stephen001)
 */

#ifndef STRINGBUILDER_H_
#define STRINGBUILDER_H_

#include "ObjectReference.h"
#include <list>

/**
 * A string builder. This class is a pretty naive implementation of a string
 * builder, that simply stores away added strings until results are required
 * from it.
 */
class StringBuilder : public DataObject {
public:
	/**
	 * Not expecting any sub-classing of this yet.
	 */
	~StringBuilder();
	/**
	 * Adds text to the builder.
	 *
	 * \param text The text to add.
	 */
	void add(char * text);
	/**
	 * Gets the result of the addition, but doesn't clear the buffer.
	 *
	 * \return The concatenated string.
	 */
	char * result();
private:
	std::list<std::string> data;
};

/**
 * BYOND Interface to make new String Builders.
 */
extern "C" __declspec(dllexport) char * new_string_builder(int argc, char ** argv);
/**
 * BYOND Interface to add to a String Builder.
 */
extern "C" __declspec(dllexport) char * add_string_builder(int argc, char ** argv);
/**
 * BYOND Interface to get the result from a String Builder.
 */
extern "C" __declspec(dllexport) char * result_string_builder(int argc, char ** argv);
/**
 * BYOND Interface to destroy String Builders.
 */
extern "C" __declspec(dllexport) char * delete_string_builder(int argc, char ** argv);

#endif /* STRINGBUILDER_H_ */
