/**
 * A string builder, used to efficiently put together new strings. Compared with simply
 * adding the text together, this datum saves a lot of expensive internal work until you
 * call result(), to avoid duplicating the effort. If you are adding strings a lot in a
 * loop, this will boost your performance.
 *
 * @since 0.0.1
 */
StringBuilder
	var
		id

	/**
	 * Simply constructs a new, empty string builder.
	 */
	New()
		src.id = call(__get_stringutilities_dll_name(), "new_string_builder")()

	/**
	 * Just cleans up the high performance code.
	 */
	Del()
		call(__get_stringutilities_dll_name(), "delete_string_builder")(src.id)

	proc
		/**
		 * Adds text to the builder. This will append the text to whatever has been added
		 * before, as far as you can tell. Internally it is held as a chunk of the string,
		 * but not actually appended yet.
		 */
		add(var/T as text)
			call(__get_stringutilities_dll_name(), "add_string_builder")(src.id, T)

		/**
		 * Returns the result of the builder. This does not clear the internals, so you can
		 * keep adding if you want. To clear, just make a new builder.
		 */
		result()
			return call(__get_stringutilities_dll_name(), "result_string_builder")(src.id)